commit d7d23934bc1da583fa7c95d928aeb2ac3f170b72
Author: Günter Milde <[email protected]>
Date: Fri Sep 16 21:01:55 2016 +0200
ctests: rename pattern file "suspiciousTests" to "invertedTests". part 2
---
development/autotests/ExportTests.cmake | 10 +++++-----
1 files changed, 5 insertions(+), 5 deletions(-)
diff --git a/development/autotests/ExportTests.cmake
b/development/autotests/ExportTests.cmake
index 7dd6168..1ac4879 100644
--- a/development/autotests/ExportTests.cmake
+++ b/development/autotests/ExportTests.cmake
@@ -123,18 +123,18 @@ function(join rvalues glue routput)
set(${routput} ${out} PARENT_SCOPE)
endfunction()
-macro(maketestname testname inverted listsuspicious listignored listunreliable
listlabels)
+macro(maketestname testname inverted listinverted listignored listunreliable
listlabels)
# initialize output variable
set(${inverted} 0)
string(REGEX MATCH "\\/[a-z][a-z](_[A-Z][A-Z])?\\/" _v ${${testname}})
if(_v)
string(REGEX REPLACE "\\/" "" _v ${_v})
- set(listsuspiciousx ${listsuspicious}_${_v})
+ set(listinvertedx ${listinverted}_${_v})
set(listignoredx ${listignored}_${_v})
set(listunreliablex ${listunreliable}_${_v})
set(listsuspendedx suspendedTests_${_v})
else()
- set(listsuspiciousx ${listsuspicious})
+ set(listinvertedx ${listinverted})
set(listignoredx ${listignored})
set(listunreliablex ${listunreliable})
set(listsuspendedx suspendedTests)
@@ -149,10 +149,10 @@ macro(maketestname testname inverted listsuspicious
listignored listunreliable l
list(REMOVE_ITEM sublabel "export" "inverted" "templates" "mathmacros"
"manuals" "autotests")
else()
string(REGEX MATCH
"(^check_load|_(systemF|texF|pdf3|pdf2|pdf|dvi|lyx[0-9][0-9]|xhtml)$)" _v
${${testname}})
# check if test _may_ be in listsuspicious
set(sublabel2 "")
if (_v)
- findexpr(mfound ${testname} ${listsuspiciousx} sublabel2)
+ findexpr(mfound ${testname} ${listinvertedx} sublabel2)
else()
set(mfound OFF)
endif()
@@ -149,10 +149,10 @@ macro(maketestname testname inverted listsuspicious
"(^check_load|_(systemF|texF|pdf3|pdf2|pdf|dvi|lyx[0-9][0-9]|xhtml)$)" _v
${${testname}})
- # check if test _may_ be in listsuspicious
+ # check if test _may_ be in listinverted
set(sublabel2 "")
if (_v)